pub struct ImageCacheService { /* private fields */ }Implementations
Sourceimpl ImageCacheService
impl ImageCacheService
Sourcepub async fn new(cfg: Arc<Configuration>) -> Self
pub async fn new(cfg: Arc<Configuration>) -> Self
Create a new image cache service.
Panics
This function will panic if the image cache could not be created.
Sourcepub async fn get_image_by_url(
&self,
url: &str,
user_id: UserId,
) -> Result<Bytes, Error>
pub async fn get_image_by_url( &self, url: &str, user_id: UserId, ) -> Result<Bytes, Error>
Get an image from the url and insert it into the cache if it isn’t cached already. Unauthenticated users can only get already cached images.
Errors
Return a Error::Unauthenticated if the user has not been authenticated.