pub struct BytesCache { /* private fields */ }Implementations
Sourceimpl BytesCache
impl BytesCache
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
pub fn with_entry_size_limit(entry_size_limit: usize) -> Self
Sourcepub fn with_capacity_and_entry_size_limit(
capacity: usize,
entry_size_limit: usize,
) -> Result<Self, Error>
pub fn with_capacity_and_entry_size_limit( capacity: usize, entry_size_limit: usize, ) -> Result<Self, Error>
Helper to create a new bytes cache with both an individual entry and size limit.
Errors
This function will return Error::EntrySizeLimitExceedsTotalCapacity if the specified size is too large.
pub async fn get(&self, key: &str) -> Option<BytesCacheEntry>
pub async fn len(&self) -> usize
pub async fn is_empty(&self) -> bool
pub fn total_size(&self) -> usize
Sourcepub async fn set(
&mut self,
key: String,
bytes: Bytes,
) -> Result<Option<BytesCacheEntry>, Error>
pub async fn set( &mut self, key: String, bytes: Bytes, ) -> Result<Option<BytesCacheEntry>, Error>
Adds a image to the cache.
Errors
This function will return an error if there is not enough free size.
pub fn pop(&mut self) -> Option<BytesCacheEntry>