pub struct JsonWebToken { /* private fields */ }Implementations
Sourceimpl JsonWebToken
impl JsonWebToken
pub fn new(cfg: Arc<Configuration>) -> Self
Sourcepub async fn sign(&self, user: UserCompact) -> String
pub async fn sign(&self, user: UserCompact) -> String
Create Json Web Token.
Panics
This function will panic if the default encoding algorithm does not ç match the encoding key.
Sourcepub async fn verify(&self, token: &str) -> Result<UserClaims, ServiceError>
pub async fn verify(&self, token: &str) -> Result<UserClaims, ServiceError>
Verify Json Web Token.
Errors
This function will return an error if the JWT is not good or expired.